@@ -16,12 +16,23 @@
 #include "imapfilter.h"
 #include "session.h"
 
-SSL_CTX *ssl23ctx, *tls1ctx;
+
+#if OPENSSL_VERSION_NUMBER >= 0x1010000fL
+SSL_CTX *sslctx = NULL;
+#else
+SSL_CTX *ssl23ctx = NULL;
 #ifndef OPENSSL_NO_SSL3_METHOD
-SSL_CTX *ssl3ctx;
+SSL_CTX *ssl3ctx = NULL;
+#endif
+#ifndef OPENSSL_NO_TLS1_METHOD
+SSL_CTX *tls1ctx = NULL;
+#endif
+#ifndef OPENSSL_NO_TLS1_1_METHOD
+SSL_CTX *tls11ctx = NULL;
+#endif
+#ifndef OPENSSL_NO_TLS1_2_METHOD
+SSL_CTX *tls12ctx = NULL;
 #endif
-#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
-SSL_CTX *tls11ctx, *tls12ctx;
 #endif
 
 
@@ -92,33 +103,39 @@ int
 open_secure_connection(session *ssn)
 {
 	int r, e;
-	SSL_CTX *ctx;
+	SSL_CTX *ctx = NULL;
 
-	if (!ssn->sslproto) {
+#if OPENSSL_VERSION_NUMBER >= 0x1010000fL
+	if (sslctx)
+		ctx = sslctx;
+#else
+	if (ssl23ctx)
 		ctx = ssl23ctx;
-	} else if (!strcasecmp(ssn->sslproto, "ssl3")) {
+
+	if (ssn->sslproto) {
 #ifndef OPENSSL_NO_SSL3_METHOD
-		ctx = ssl3ctx;
-#else
-		error("protocol SSLv3 not supported by current build\n");
+		if (ssl3ctx && !strcasecmp(ssn->sslproto, "ssl3"))
+			ctx = ssl3ctx;
+#endif
+#ifndef OPENSSL_NO_TLS1_METHOD
+		if (tls1ctx && !strcasecmp(ssn->sslproto, "tls1"))
+			ctx = tls1ctx;
+#endif
+#ifndef OPENSSL_NO_TLS1_1_METHOD
+		if (tls11ctx && !strcasecmp(ssn->sslproto, "tls1.1"))
+			ctx = tls11ctx;
+#endif
+#ifndef OPENSSL_NO_TLS1_2_METHOD
+		if (tls12ctx && !strcasecmp(ssn->sslproto, "tls1.2"))
+			ctx = tls12ctx;
+#endif
+	}
+#endif
+
+	if (ctx == NULL) {
+		error("initiating SSL connection to %s; protocol version "
+		      "not supported by current build", ssn->server);
 		goto fail;
-#endif
-	} else if (!strcasecmp(ssn->sslproto, "tls1")) {
-		ctx = tls1ctx;
-	} else if (!strcasecmp(ssn->sslproto, "tls1.1")) {
-#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
-		ctx = tls11ctx;
-#else
-		ctx = tls1ctx;
-#endif
-	} else if (!strcasecmp(ssn->sslproto, "tls1.2")) {
-#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
-		ctx = tls12ctx;
-#else
-		ctx = tls1ctx;
-#endif
-	} else {
-		ctx = ssl23ctx;
 	}
 
 	if (!(ssn->sslconn = SSL_new(ctx)))
